==> qtjambi-qt3drender-debuginfo-macos-5.15.17.jar: sources/QtJambi3DRender/QTextureWrapMode_shell.h <==
#ifndef QTEXTUREWRAPMODE_SHELL_H
#define QTEXTUREWRAPMODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qtexturewrapmode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QTextureWrapMode_shell : public Qt3DRender::QTextureWrapMode, public QtJambiShellInterface
{
public:
    QTextureWrapMode_shell(Qt3DRender::QTextureWrapMode::WrapMode wrapMode0 = Qt3DRender::QTextureWrapMode::ClampToEdge, QObject* parent1 = nullptr);
    QTextureWrapMode_shell(Qt3DRender::QTextureWrapMode::WrapMode x0, Qt3DRender::QTextureWrapMode::WrapMode y1, Qt3DRender::QTextureWrapMode::WrapMode z2, QObject* parent3 = nullptr);
    ~QTextureWrapMode_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextureWrapMode_access : public Qt3DRender::QTextureWrapMode
{
};

#endif // QTEXTUREWRAPMODE_SHELL_H

==> qtjambi-qt3drender-debuginfo-macos-6.5.3.jar: sources/QtJambi3DRender/QTextureWrapMode_shell.h <==
#ifndef QTEXTUREWRAPMODE_SHELL_H
#define QTEXTUREWRAPMODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qtexturewrapmode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QTextureWrapMode_shell : public Qt3DRender::QTextureWrapMode, public QtJambiShellInterface
{
public:
    QTextureWrapMode_shell(Qt3DRender::QTextureWrapMode::WrapMode wrapMode0 = Qt3DRender::QTextureWrapMode::ClampToEdge, QObject* parent1 = nullptr);
    QTextureWrapMode_shell(Qt3DRender::QTextureWrapMode::WrapMode x0, Qt3DRender::QTextureWrapMode::WrapMode y1, Qt3DRender::QTextureWrapMode::WrapMode z2, QObject* parent3 = nullptr);
    ~QTextureWrapMode_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextureWrapMode_access : public Qt3DRender::QTextureWrapMode
{
};

#endif // QTEXTUREWRAPMODE_SHELL_H
